window.Gleam.initSearch([{"doc":"glerm","title":"glerm","content":"# glerm\n\n[![Package Version](https://img.shields.io/hexpm/v/glerm)](https://hex.pm/packages/glerm)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glerm/)\n\nA Gleam wrapper around `crossterm` to create terminal applications\n\n## Quick start\n\n### Caveats\n\nCurrently, this only works on Linux. Gleam doesn&#39;t support any mechanism to\nbuild the NIFs on your machine. To get around this for now, I am shipping\npre-compiled library files in the `priv/` directory.\n\nThe `.dll` for windows does actually allow the program to run. Most of the\nmethods seem to work, but unfortunately the blocking `event::read()` call\njust hangs. I expect this is some interaction between `erlang`, `crossterm`,\nand Windows. I may try to look more into this, but right now I don&#39;t really\nknow what the issue is. Would love some help with this if possible!\n\nI tried to build this on my Intel Macbook, but got some errors from `rustler`.\nI&#39;m not sure if that&#39;s not considered a supported platform anymore by them,\nbut it&#39;s also currently not working. Any help with that would also be\nappreciated.\n\nI don&#39;t have access to anything ARM, so unfortunately will not be able to\nprovide anything in that regard.\n\n### Getting started\n\nThe docs should hopefully be helpful. Additionally, there is at least one\nexample usage in `examples/` that you can run with `gleam run` (if you are\nusing a version of Gleam that supports path dependencies).\n\n## Installation\n\nIf available on Hex this package can be added to your Gleam project:\n\n```sh\ngleam add glerm\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/glerm&gt;.\n","url":"index.html"},{"doc":"glerm","title":"Event","content":"pub type Event {\n  Focus(event: FocusEvent)\n  Key(key: KeyCode, modifier: Option(Modifier))\n  Mouse(event: MouseEvent)\n  Resize(Int, Int)\n  Unknown(tag: String, message: Dynamic)\n}\n The possible events coming back from the terminal. `Unknown` should\n realistically never happen, since this library controls both ends of the\n message passing.\nFocus(event: FocusEvent)\n\n\nKey(key: KeyCode, modifier: Option(Modifier))\n\n\nMouse(event: MouseEvent)\n\n\nResize(Int, Int)\n\n\nUnknown(tag: String, message: Dynamic)\n\n\nSynonyms:\nglerm.Event\nglerm Event","url":"glerm.html#Event"},{"doc":"glerm","title":"EventSubject","content":"pub type EventSubject =\n  Subject(Event)\n\n\nSynonyms:\nglerm.EventSubject\nglerm EventSubject","url":"glerm.html#EventSubject"},{"doc":"glerm","title":"FocusEvent","content":"pub type FocusEvent {\n  Lost\n  Gained\n}\n When the terminal window is focused or un-focused.\nLost\n\n\nGained\n\n\nSynonyms:\nglerm.FocusEvent\nglerm FocusEvent","url":"glerm.html#FocusEvent"},{"doc":"glerm","title":"KeyCode","content":"pub type KeyCode {\n  Character(String)\n  Enter\n  Backspace\n  Left\n  Right\n  Down\n  Up\n  Unsupported\n}\n A particular keyboard key that was pressed. Either a character with its\n value, or a special key. The `Unsupported` is for things like `PageUp`, etc\n that I&#39;m just not handling yet.\nCharacter(String)\n\n\nEnter\n\n\nBackspace\n\n\nLeft\n\n\nRight\n\n\nDown\n\n\nUp\n\n\nUnsupported\n\n\nSynonyms:\nglerm.KeyCode\nglerm KeyCode","url":"glerm.html#KeyCode"},{"doc":"glerm","title":"ListenerMessage","content":"pub type ListenerMessage(user_message) {\n  Term(Event)\n  User(user_message)\n}\n\nTerm(Event)\n\n\nUser(user_message)\n\n\nSynonyms:\nglerm.ListenerMessage\nglerm ListenerMessage","url":"glerm.html#ListenerMessage"},{"doc":"glerm","title":"ListenerSpec","content":"pub type ListenerSpec(state, user_message) {\n  ListenerSpec(\n    init: fn() -&gt; #(state, Option(Selector(user_message))),\n    loop: fn(ListenerMessage(user_message), state) -&gt;\n      actor.Next(state),\n  )\n}\n\nListenerSpec(\n  init: fn() -&gt; #(state, Option(Selector(user_message))),\n  loop: fn(ListenerMessage(user_message), state) -&gt;\n    actor.Next(state),\n)\n\n\nSynonyms:\nglerm.ListenerSpec\nglerm ListenerSpec","url":"glerm.html#ListenerSpec"},{"doc":"glerm","title":"ListenerSubject","content":"pub type ListenerSubject(user_message) =\n  Subject(ListenerMessage(user_message))\n\n\nSynonyms:\nglerm.ListenerSubject\nglerm ListenerSubject","url":"glerm.html#ListenerSubject"},{"doc":"glerm","title":"Modifier","content":"pub type Modifier {\n  Shift\n  Alt\n  Control\n}\n These represent the noted keys being held down when another action is taken,\n like pressing another key or mouse button. For certain keys, things like\n `Shift` will not be set, but instead return something like `A`.\nShift\n\n\nAlt\n\n\nControl\n\n\nSynonyms:\nglerm.Modifier\nglerm Modifier","url":"glerm.html#Modifier"},{"doc":"glerm","title":"MouseButton","content":"pub type MouseButton {\n  MouseLeft\n  MouseRight\n  MouseMiddle\n}\n Which mouse button was pressed. These are prefixed with `Mouse` in order to\n avoid conflicting with the arrow keys defined in `KeyCode`.\nMouseLeft\n\n\nMouseRight\n\n\nMouseMiddle\n\n\nSynonyms:\nglerm.MouseButton\nglerm MouseButton","url":"glerm.html#MouseButton"},{"doc":"glerm","title":"MouseEvent","content":"pub type MouseEvent {\n  MouseDown(button: MouseButton, modifier: Option(Modifier))\n  MouseUp(button: MouseButton, modifier: Option(Modifier))\n  Drag(button: MouseButton, modifier: Option(Modifier))\n  Moved\n  ScrollDown\n  ScrollUp\n}\n The possible types of mouse events. I think most of these will also\n have the mouse cursor position attached. That is not supported at the moment.\nMouseDown(button: MouseButton, modifier: Option(Modifier))\n\n\nMouseUp(button: MouseButton, modifier: Option(Modifier))\n\n\nDrag(button: MouseButton, modifier: Option(Modifier))\n\n\nMoved\n\n\nScrollDown\n\n\nScrollUp\n\n\nSynonyms:\nglerm.MouseEvent\nglerm MouseEvent","url":"glerm.html#MouseEvent"},{"doc":"glerm","title":"clear","content":"pub external fn clear() -&gt; Nil\n Fully clears the terminal window\nSynonyms:\nglerm.clear\nglerm clear","url":"glerm.html#clear"},{"doc":"glerm","title":"disable_mouse_capture","content":"pub external fn disable_mouse_capture() -&gt; Result(Nil, Nil)\n This will stop the capture of mouse events in the terminal.\nSynonyms:\nglerm.disable_mouse_capture\nglerm disable_mouse_capture","url":"glerm.html#disable_mouse_capture"},{"doc":"glerm","title":"disable_raw_mode","content":"pub external fn disable_raw_mode() -&gt; Result(Nil, Nil)\n Turns off raw mode. This will disable the features described in\n `enable_raw_mode`.\nSynonyms:\nglerm.disable_raw_mode\nglerm disable_raw_mode","url":"glerm.html#disable_raw_mode"},{"doc":"glerm","title":"draw","content":"pub external fn draw(\n  commands: List(#(Int, Int, String)),\n) -&gt; Result(Nil, Nil)\n Write some string to the screen at the given #(column, row) coordinate\nSynonyms:\nglerm.draw\nglerm draw","url":"glerm.html#draw"},{"doc":"glerm","title":"enable_mouse_capture","content":"pub external fn enable_mouse_capture() -&gt; Result(Nil, Nil)\n This enables the capturing of mouse events. Without this, those event types\n will not be emitted by the NIF.\nSynonyms:\nglerm.enable_mouse_capture\nglerm enable_mouse_capture","url":"glerm.html#enable_mouse_capture"},{"doc":"glerm","title":"enable_raw_mode","content":"pub external fn enable_raw_mode() -&gt; Result(Nil, Nil)\n Enables &quot;raw mode&quot; for the terminal. This will do a better job than I can\n at explaining what all that entails:\n\n   https://docs.rs/crossterm/latest/crossterm/terminal/index.html#raw-mode\n\n If you want to control the entire screen, capture all input events, and\n place the cursor anywhere, this is what you want.\nSynonyms:\nglerm.enable_raw_mode\nglerm enable_raw_mode","url":"glerm.html#enable_raw_mode"},{"doc":"glerm","title":"enter_alternate_screen","content":"pub external fn enter_alternate_screen() -&gt; Result(Nil, Nil)\n This will create a new terminal &quot;window&quot; that you can interact with. This\n will preserve the user&#39;s existing terminal when exiting the program, or\n calling `leave_alternate_screen`.\nSynonyms:\nglerm.enter_alternate_screen\nglerm enter_alternate_screen","url":"glerm.html#enter_alternate_screen"},{"doc":"glerm","title":"leave_alternate_screen","content":"pub external fn leave_alternate_screen() -&gt; Result(Nil, Nil)\n See:  `enter_alternate_screen`\nSynonyms:\nglerm.leave_alternate_screen\nglerm leave_alternate_screen","url":"glerm.html#leave_alternate_screen"},{"doc":"glerm","title":"move_to","content":"pub external fn move_to(column: Int, row: Int) -&gt; Nil\n Moves the cursor to the given location\nSynonyms:\nglerm.move_to\nglerm move_to","url":"glerm.html#move_to"},{"doc":"glerm","title":"print","content":"pub external fn print(data: BitString) -&gt; Result(Nil, Nil)\n Writes the given text wherever the cursor is\nSynonyms:\nglerm.print\nglerm print","url":"glerm.html#print"},{"doc":"glerm","title":"selector","content":"pub fn selector() -&gt; Selector(Event)\n The events from the NIF are sent as messages to the calling process. These\n do not go through a `process.Subject`, so they need to be explicitly\n extracted from the mailbox. This selector will grab the given `Event`s for\n each message that comes in.\nSynonyms:\nglerm.selector\nglerm selector","url":"glerm.html#selector"},{"doc":"glerm","title":"size","content":"pub external fn size() -&gt; Result(#(Int, Int), Nil)\n Gives back the #(column, row) count of the current terminal. This can be\n called to get the initial size, and then updated when `Resize` events\n come in.\nSynonyms:\nglerm.size\nglerm size","url":"glerm.html#size"},{"doc":"glerm","title":"start_listener","content":"pub fn start_listener(initial_state: a, loop: fn(Event, a) -&gt;\n    Next(a)) -&gt; Result(Subject(Event), StartError)\n If you are not planning on sending custom messages to the terminal listener,\n this method is the simplest. Give an initial state for the actor, and the\n loop will receive only `Event`s and your provided state. To allow this\n actor to receive additional user-defined messages, see `start_listener_spec`\nSynonyms:\nglerm.start_listener\nglerm start_listener","url":"glerm.html#start_listener"},{"doc":"glerm","title":"start_listener_spec","content":"pub fn start_listener_spec(spec: ListenerSpec(a, b)) -&gt; Result(\n  Subject(ListenerMessage(b)),\n  StartError,\n)\n This will start the NIF listener and set up the `Event` selector. The spec\n argument allows for behavior during the initialization of the actor. That\n function returns the initial state, and an optional user selector. This\n allows this actor to also receive any user-defined messages.\nSynonyms:\nglerm.start_listener_spec\nglerm start_listener_spec","url":"glerm.html#start_listener_spec"},{"doc":"glerm","title":"glerm","content":"","url":"glerm.html"}]);